@@ -4,14 +4,15 @@ misc. stuff we've not found a spot for yet.
 
 __all__ = (
     "ChunkedDataDict", "IncrementalsDict", "PayloadDict",
-    "chunked_data", "collapsed_restrict_to_data", "incremental_chunked",
-    "incremental_expansion", "incremental_expansion_license",
+    "chunked_data", "collapsed_restrict_to_data", "get_relative_dosym_target",
+    "incremental_chunked", "incremental_expansion",
+    "incremental_expansion_license",
     "non_incremental_collapsed_restrict_to_data", "optimize_incrementals",
     "sort_keywords",
 )
 
+import os.path
 from collections import defaultdict, namedtuple
-from concurrent.futures import ThreadPoolExecutor
 from functools import partial
 from itertools import chain
 
@@ -550,18 +551,16 @@ class PayloadDict(ChunkedDataDict):
 
 def run_sanity_checks(pkgs, domain, threads=None):
     """Run all sanity checks for a sequence of packages."""
-    failures = defaultdict(list)
-    sanity_check = lambda pkg_ops: pkg_ops.sanity_check()
+    sanity_failures = defaultdict(list)
+    # TODO: parallelize this across separate processes
+    for pkg in pkgs:
+        pkg_ops = domain.pkg_operations(pkg)
+        if pkg_ops.supports("sanity_check") and (failures := pkg_ops.sanity_check()):
+            sanity_failures[pkg] = failures
+    return sanity_failures
 
-    # generator of pkgs supporting sanity checks
-    def _filter_pkgs(pkgs):
-        for pkg in pkgs:
-            pkg_ops = domain.pkg_operations(pkg)
-            if pkg_ops.supports("sanity_check"):
-                yield pkg_ops
 
-    with ThreadPoolExecutor(max_workers=threads) as executor:
-        for pkg, failed in executor.map(sanity_check, _filter_pkgs(pkgs)):
-            if failed:
-                failures[pkg].extend(failed)
-    return failures
+def get_relative_dosym_target(source, target):
+    """Get relative path from target to source, for symlink target."""
+    # NB: as dosym arg, initial slash can be omitted
+    return os.path.relpath(source, os.path.join('/', os.path.dirname(target)))
