@@ -40,14 +40,16 @@ from .eapi import get_eapi
 class repo_operations(_repo_ops.operations):
 
     def _cmd_implementation_manifest(self, domain, restriction, observer,
-                                     mirrors=False, force=False):
+                                     mirrors=False, force=False, distdir=None):
         manifest_config = self.repo.config.manifests
         if manifest_config.disabled:
             observer.info(f'{self.repo.repo_id} repo has manifests disabled')
             return
         required_chksums = set(manifest_config.required_hashes)
         write_chksums = manifest_config.hashes
-        distdir = domain.fetcher.distdir
+
+        if distdir is None:
+            distdir = domain.distdir
         ret = set()
 
         matches = self.repo.itermatch(restriction, sorter=sorted)
@@ -100,14 +102,9 @@ class repo_operations(_repo_ops.operations):
             if not force and manifest.distfiles.keys() == pkgdir_fetchables.keys():
                 continue
 
-            pkg_ops = domain.pkg_operations(pkg, observer=observer)
-            if not pkg_ops.supports("fetch"):
-                observer.error(f"{key}: fetching unsupported, can't generate manifest")
-                ret.add(key)
-                continue
-
             # fetch distfiles
-            if not pkg_ops.fetch(list(fetchables.values()), observer):
+            pkg_ops = domain.pkg_operations(pkg, observer=observer)
+            if not pkg_ops.fetch(list(fetchables.values()), observer, distdir=distdir):
                 ret.add(key)
                 continue
 
@@ -179,28 +176,29 @@ class ProvidesRepo(util.SimpleTree):
 
     class PkgProvided(ebuild_src.base):
 
-        __slots__ = ('use',)
+        __slots__ = ('arches', 'use')
 
         package_is_real = False
         __inst_caching__ = True
 
         @property
         def keywords(self):
-            return InvertedContains(())
+            return self.arches
 
-        def __init__(self, *a, **kwds):
-            super().__init__(*a, **kwds)
+        def __init__(self, *args, arches=(), **kwargs):
+            super().__init__(*args, **kwargs)
             object.__setattr__(self, "use", [])
+            object.__setattr__(self, "arches", arches)
             object.__setattr__(self, "data", {"SLOT": "0"})
             object.__setattr__(self, "eapi", get_eapi('0'))
 
-    def __init__(self, pkgs, repo_id='package.provided'):
+    def __init__(self, pkgs, arches, repo_id='package.provided'):
         d = {}
         for pkg in pkgs:
             d.setdefault(pkg.category, {}).setdefault(pkg.package, []).append(pkg.fullver)
         intermediate_parent = self.PkgProvidedParent()
         super().__init__(
-            d, pkg_klass=partial(self.PkgProvided, intermediate_parent),
+            d, pkg_klass=partial(self.PkgProvided, intermediate_parent, arches=arches),
             livefs=True, frozen=True, repo_id=repo_id)
         intermediate_parent._parent_repo = self
 
@@ -399,6 +397,23 @@ class UnconfiguredTree(prototype.tree):
             pass
         return ImmutableDict(mirrors)
 
+    @klass.jit_attr
+    def use_expand_sort(self):
+        """Inherited mapping of USE_EXPAND sorting keys for the repo."""
+        d = {}
+        for repo in self.trees:
+            d.update(repo.config.use_expand_sort)
+        return ImmutableDict(d)
+
+    def use_expand_sorter(self, group):
+        """Sorting function for a given USE_EXPAND group."""
+        try:
+            ordering = self.use_expand_sort[group.lower()]
+            return lambda k: ordering.get(k, -1)
+        except KeyError:
+            # nonexistent USE_EXPAND group
+            return lambda k: k
+
     @klass.jit_attr
     def category_dirs(self):
         try:
@@ -648,17 +663,15 @@ class ConfiguredTree(configured.tree):
     config_wrappables = {
         x: klass.alias_method("evaluate_depset")
         for x in (
-            "bdepend", "depend", "rdepend", "pdepend",
+            "bdepend", "depend", "rdepend", "pdepend", "idepend",
             "fetchables", "license", "src_uri", "restrict", "required_use",
         )
     }
 
-    def __init__(self, raw_repo, domain, domain_settings, fetcher=None):
+    def __init__(self, raw_repo, domain, domain_settings):
         """
         :param raw_repo: :obj:`UnconfiguredTree` instance
         :param domain_settings: environment settings to bind
-        :param fetcher: :obj:`pkgcore.fetch.base.fetcher` instance to use
-            for getting access to fetchable files
         """
         required_settings = {'USE', 'CHOST'}
         if missing_settings := required_settings.difference(domain_settings):
@@ -687,7 +700,6 @@ class ConfiguredTree(configured.tree):
 
         self.domain = domain
         self.domain_settings = domain_settings
-        self._fetcher_override = fetcher
         self._delayed_iuse = partial(make_kls(InvertedContains), InvertedContains)
 
     def _wrap_attr(config_wrappables):
@@ -747,8 +759,4 @@ class ConfiguredTree(configured.tree):
                 self._get_delayed_immutable, pkg, immutable)}
 
     def _generate_pkg_operations(self, domain, pkg, **kwds):
-        fetcher = self._fetcher_override
-        if fetcher is None:
-            fetcher = domain.fetcher
-        return ebd.src_operations(
-            domain, pkg, pkg.repo.eclass_cache, fetcher=fetcher, **kwds)
+        return ebd.src_operations(domain, pkg, pkg.repo.eclass_cache, **kwds)
