@@ -12,23 +12,29 @@ import os
 from snakeoil import klass
 from snakeoil.dependant_methods import ForcedDepends
 from snakeoil.osutils import pjoin
-from snakeoil.sequences import iflatten_instance
 
-from .. import fetch as _fetch_module
 from .. import operations as _operations_mod
 from ..exceptions import PkgcoreUserException
+from ..fetch import custom as fetch_custom
 from ..fetch import errors as fetch_errors
 
 
 class fetch_base:
 
-    def __init__(self, domain, pkg, fetchables, fetcher):
+    def __init__(self, domain, pkg, fetchables, distdir=None):
         self.verified_files = {}
         self._basenames = set()
         self.domain = domain
         self.pkg = pkg
         self.fetchables = fetchables
-        self.fetcher = fetcher
+        self.distdir = distdir if distdir is not None else domain.distdir
+
+        # create fetcher
+        fetchcmd = domain.settings['FETCHCOMMAND']
+        resumecmd = domain.settings.get('RESUMECOMMAND', fetchcmd)
+        attempts = int(domain.settings.get('FETCH_ATTEMPTS', 10))
+        self.fetcher = fetch_custom.fetcher(
+            self.distdir, fetchcmd, resumecmd, attempts=attempts)
 
     def fetch_all(self, observer):
         # TODO: add parallel fetch support
@@ -36,10 +42,7 @@ class fetch_base:
         for fetchable in self.fetchables:
             if not self.fetch_one(fetchable, observer):
                 failures.append(fetchable)
-        if failures:
-            self._failed_fetch(failures, observer)
-            return False
-        return True
+        return self.verified_files, failures
 
     def fetch_one(self, fetchable, observer, retry=False):
         if fetchable.filename in self._basenames:
@@ -50,9 +53,9 @@ class fetch_base:
             fp = self.fetcher(fetchable)
         except fetch_errors.ChksumFailure as e:
             # checksum failed, rename file and try refetching
-            path = pjoin(self.fetcher.distdir, fetchable.filename)
+            path = pjoin(self.distdir, fetchable.filename)
             failed_filename = f'{fetchable.filename}._failed_chksum_'
-            failed_path = pjoin(self.fetcher.distdir, failed_filename)
+            failed_path = pjoin(self.distdir, failed_filename)
             os.rename(path, failed_path)
             if retry:
                 raise
@@ -61,7 +64,7 @@ class fetch_base:
             observer.flush()
             # refetch directly from upstream
             return self.fetch_one(fetchable.upstream, observer, retry=True)
-        except fetch_errors.FetchFailed as e:
+        except fetch_errors.FetchFailed:
             fp = None
         if fp is None:
             return False
@@ -69,18 +72,6 @@ class fetch_base:
         self._basenames.add(fetchable.filename)
         return True
 
-    def _failed_fetch(self, fetchables, observer):
-        # run pkg_nofetch phase for fetch restricted pkgs
-        if 'fetch' in self.pkg.restrict:
-            # This requires wrapped packages from a configured repo, otherwise
-            # buildables aren't available to run the pkg_nofetch phase.
-            configured_repo = self.domain.unfiltered_repos[self.pkg.repo.repo_id]
-            pkgwrap = configured_repo.package_class(self.pkg)
-            build_ops = self.domain.build_pkg(pkgwrap, observer, failed=True)
-            build_ops.nofetch()
-            build_ops.cleanup(force=True)
-        observer.error("failed fetching files: %s::%s", self.pkg.cpvstr, self.pkg.repo.repo_id)
-
 
 class operations(_operations_mod.base):
 
@@ -91,6 +82,7 @@ class operations(_operations_mod.base):
         self.observer = observer
         self.pkg = pkg
         self.domain = domain
+        self.verified_files = None
         super().__init__(disable_overrides, enable_overrides)
 
     def _cmd_api_info(self):
@@ -121,51 +113,31 @@ class operations(_operations_mod.base):
         return self._cmd_implementation_configure(
             self._get_observer(observer))
 
-    def _cmd_check_support_fetch(self):
-        return self._find_fetcher() is not None
-
-    def _generate_fetchables(self, mirroring=False):
-        pkg = self.pkg
-        if not mirroring:
-            return pkg.fetchables
-        pkg = getattr(pkg, '_raw_pkg', pkg)
-        return tuple(iflatten_instance(pkg.fetchables, _fetch_module.fetchable))
-
-    @klass.cached_property
-    def _fetch_op(self):
-        return self._fetch_kls(
-            self.domain, self.pkg,
-            self._generate_fetchables(),
-            self._find_fetcher())
-
-    @klass.cached_property
-    def _mirror_op(self):
-        return self._fetch_kls(
-            self.domain, self.pkg,
-            self._generate_fetchables(mirroring=True),
-            self._find_fetcher())
-
     @_operations_mod.is_standalone
-    def _cmd_api_fetch(self, fetchables=None, observer=klass.sentinel):
+    def _cmd_api_fetch(self, fetchables=None, observer=klass.sentinel, distdir=None):
         observer = observer if observer is not klass.sentinel else self.observer
         if fetchables is None:
-            fetcher = self._fetch_op
-        else:
-            if not isinstance(fetchables, (tuple, list)):
-                fetchables = [fetchables]
-            fetcher = self._fetch_kls(self.domain, self.pkg, fetchables, self._find_fetcher())
-        return fetcher.fetch_all(self._get_observer(observer))
+            fetchables = self.pkg.fetchables
+        elif not isinstance(fetchables, (tuple, list)):
+            fetchables = [fetchables]
+        fetcher = self._fetch_kls(self.domain, self.pkg, fetchables, distdir)
+        verified, failures = fetcher.fetch_all(self._get_observer(observer))
 
-    @_operations_mod.is_standalone
-    def _cmd_api_mirror(self, observer=klass.sentinel):
-        observer = observer if observer is not klass.sentinel else self.observer
-        return self._mirror_op.fetch_all(self._get_observer(observer))
+        if failures:
+            # run pkg_nofetch phase for fetch restricted pkgs
+            if 'fetch' in self.pkg.restrict:
+                # This requires wrapped packages from a configured repo, otherwise
+                # buildables aren't available to run the pkg_nofetch phase.
+                configured_repo = self.domain.unfiltered_repos[self.pkg.repo.repo_id]
+                pkgwrap = configured_repo.package_class(self.pkg)
+                build_ops = self.domain.build_pkg(pkgwrap, observer, failed=True)
+                build_ops.nofetch()
+                build_ops.cleanup(force=True)
+            observer.error('failed fetching files: %s::%s', self.pkg.cpvstr, self.pkg.repo.repo_id)
+            raise GenericBuildError('failed fetching required distfiles')
 
-    def _find_fetcher(self):
-        fetcher = getattr(self.pkg.repo, 'fetcher', None)
-        if fetcher is None:
-            return getattr(self.domain, 'fetcher', None)
-        return fetcher
+        self.verified_files = verified
+        return True
 
 
 class build_operations(operations):
@@ -173,13 +145,9 @@ class build_operations(operations):
     __required__ = frozenset(["build"])
 
     def _cmd_api_build(self, observer=None, failed=False, clean=True, **kwargs):
-        if failed:
-            verified_files = None
-        else:
-            verified_files = self._fetch_op.verified_files
         return self._cmd_implementation_build(
             self._get_observer(observer),
-            verified_files,
+            self.verified_files,
             clean=clean, **kwargs)
 
     def _cmd_api_buildable(self, domain):
